@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -31,6 +31,22 @@ class SizeAllocationHelper:
         else:
             self.connect("size-allocate", self.__on_size_allocate)
 
+    @property
+    def width(self):
+        """
+            Get widget width
+            @return int
+        """
+        return self.__width
+
+    @property
+    def height(self):
+        """
+            Get widget height
+            @return int
+        """
+        return self.__height
+
 #######################
 # PROTECTED           #
 #######################
