@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GObject, GLib
+from gi.repository import Gtk, GObject, GLib, Handy
 
 from lollypop.helper_art import ArtBehaviour
 from lollypop.define import App, ArtSize, MARGIN_SMALL, MARGIN
@@ -23,7 +23,7 @@ from lollypop.helper_signals import SignalsHelper, signals
 from lollypop.utils import emit_signal
 
 
-class MiniPlayer(Gtk.Overlay, SizeAllocationHelper, SignalsHelper):
+class MiniPlayer(Handy.WindowHandle, SizeAllocationHelper, SignalsHelper):
     """
         Mini player shown in folded window
     """
@@ -36,7 +36,7 @@ class MiniPlayer(Gtk.Overlay, SizeAllocationHelper, SignalsHelper):
         """
             Init mini player
         """
-        Gtk.Overlay.__init__(self)
+        Handy.WindowHandle.__init__(self)
         SizeAllocationHelper.__init__(self)
         self.__previous_artwork_id = None
         self.__per_track_cover = App().settings.get_value(
@@ -61,22 +61,21 @@ class MiniPlayer(Gtk.Overlay, SizeAllocationHelper, SignalsHelper):
         buttons_widget.show()
         buttons_widget.update()
         buttons_widget.set_property("valign", Gtk.Align.CENTER)
-        self.__artwork_widget = ArtworkPlayerWidget(
-            ArtBehaviour.CACHE | ArtBehaviour.CROP_SQUARE)
+        buttons_widget.set_margin_end(MARGIN_SMALL)
+        self.__artwork_widget = ArtworkPlayerWidget(ArtBehaviour.CROP_SQUARE)
         self.__artwork_widget.show()
         self.__artwork_widget.set_vexpand(True)
-        if App().lookup_action("miniplayer").get_state():
-            self.__artwork_widget.set_art_size(ArtSize.MEDIUM,
-                                               ArtSize.MEDIUM)
-            self.__artwork_widget.set_opacity(0.5)
-        else:
-            self.__artwork_widget.set_art_size(ArtSize.MINIPLAYER,
-                                               ArtSize.MINIPLAYER)
+        self.__artwork_widget.set_property("margin", MARGIN_SMALL)
+        self.__artwork_widget.get_style_context().add_class(
+                "transparent-cover-frame")
         self.__label_box = Gtk.Box(Gtk.Orientation.HORIZONTAL, MARGIN)
         self.__label_box.show()
+        self.__label_box.set_property("margin", MARGIN_SMALL)
         self.__label_widget = LabelPlayerWidget(False, 9)
         self.__label_widget.show()
         self.__label_widget.update()
+        self.__label_widget.set_margin_start(MARGIN_SMALL)
+        self.__label_widget.set_margin_end(MARGIN_SMALL)
         self.__artwork_button = Gtk.Image.new()
         self.__artwork_button.show()
         self.__label_box.pack_start(self.__artwork_button, False, False, 0)
@@ -88,6 +87,7 @@ class MiniPlayer(Gtk.Overlay, SizeAllocationHelper, SignalsHelper):
         button.set_property("valign", Gtk.Align.CENTER)
         button.connect("clicked", self.__on_button_clicked)
         button.set_image(self.__label_box)
+        button.set_margin_start(MARGIN_SMALL)
         self.__background = Gtk.Image()
         self.__background.show()
         # Assemble UI
@@ -95,12 +95,14 @@ class MiniPlayer(Gtk.Overlay, SizeAllocationHelper, SignalsHelper):
         self.__box.pack_start(bottom_box, False, False, 0)
         bottom_box.pack_start(button, True, True, 0)
         bottom_box.pack_end(buttons_widget, False, False, 0)
-        bottom_box.set_size_request(-1, 68)
         self.__revealer.add(self.__revealer_box)
         self.__revealer_box.pack_start(self.__artwork_widget, False, True, 0)
         self.__revealer_box.pack_end(self.__progress_widget, False, True, 0)
-        self.add(self.__background)
-        self.add_overlay(self.__box)
+        overlay = Gtk.Overlay.new()
+        overlay.show()
+        overlay.add(self.__background)
+        overlay.add_overlay(self.__box)
+        self.add(overlay)
         return [
             (App().player, "current-changed", "_on_current_changed")
         ]
@@ -115,7 +117,9 @@ class MiniPlayer(Gtk.Overlay, SizeAllocationHelper, SignalsHelper):
             self.__revealer.set_reveal_child(True)
             emit_signal(self, "revealed", True)
             self.__progress_widget.update()
-            self.__artwork_widget.update()
+            size = min(ArtSize.FULLSCREEN, self.width // 2)
+            self.__artwork_widget.set_art_size(size, size)
+            self.__artwork_widget.update(True)
             if App().lookup_action("miniplayer").get_state():
                 self.__artwork_button.set_from_icon_name(
                     "view-fullscreen-symbolic", Gtk.IconSize.BUTTON)
@@ -199,9 +203,13 @@ class MiniPlayer(Gtk.Overlay, SizeAllocationHelper, SignalsHelper):
             # We use parent height because we may be collapsed
             parent = self.get_parent()
             if parent is None:
-                height = allocation.height
+                height = self.height
             else:
                 height = parent.get_allocated_height()
+            if self.__revealer.get_reveal_child():
+                size = min(ArtSize.FULLSCREEN, self.width // 2)
+                self.__artwork_widget.set_art_size(size, size)
+                self.__artwork_widget.update(True)
             self.__artwork_widget.set_artwork(
                 allocation.width + 100, height + 100,
                 self.__on_artwork,
