@@ -190,7 +190,7 @@ class MtpSync(GObject.Object):
     __ENCODERS = {"convert_none": None,
                   "convert_mp3": " ! lamemp3enc target=bitrate\
                                    cbr=true bitrate=%s ! id3v2mux",
-                  "convert_vorbis": " ! vorbisenc max-bitrate=%s\
+                  "convert_vorbis": " ! vorbisenc bitrate=%s\
                                       ! oggmux",
                   "convert_flac": " ! flacenc",
                   "convert_aac": " ! faac bitrate=%s ! mp4mux"}
@@ -390,7 +390,6 @@ class MtpSync(GObject.Object):
                     track = Track(track_id)
                     f = Gio.File.new_for_uri(track.uri)
                     filename = f.get_basename()
-                    print(filename, escape(filename))
                     album_uri = self.__get_album_name(track)
                     uri = "%s/%s" % (album_uri, escape(filename))
                     (convertion_needed,
@@ -538,8 +537,7 @@ class MtpSync(GObject.Object):
                             not self.__cancellable.is_cancelled():
                         sleep(1)
                     bus.disconnect_by_func(self.__on_bus_eos)
-                    pipeline.set_state(Gst.State.PAUSED)
-                    pipeline.set_state(Gst.State.READY)
+                    bus.remove_signal_watch()
                     pipeline.set_state(Gst.State.NULL)
                     convert_file.move(
                         dst, Gio.FileCopyFlags.OVERWRITE, None, None)
