@@ -15,16 +15,16 @@ from gi.repository import Gtk, GLib, Gio, Pango
 from gettext import gettext as _
 import re
 
-from lollypop.define import App, ArtSize, ViewType, MARGIN, MARGIN_SMALL, Type
+from lollypop.define import App, ViewType, MARGIN
 from lollypop.define import ARTISTS_PATH
 from lollypop.objects_album import Album
-from lollypop.helper_art import ArtBehaviour
 from lollypop.information_store import InformationStore
 from lollypop.view_albums_list import AlbumsListView
 from lollypop.view import View
-from lollypop.utils import set_cursor_type, get_network_available
+from lollypop.utils import get_network_available
 from lollypop.utils import get_default_storage_type
-from lollypop.helper_gestures import GesturesHelper
+from lollypop.widgets_banner_information import InformationBannerWidget
+from lollypop.helper_signals import SignalsHelper, signals_map
 
 
 class ArtistRow(Gtk.ListBoxRow):
@@ -64,100 +64,92 @@ class ArtistRow(Gtk.ListBoxRow):
         return self.__page_id
 
 
-class InformationView(View):
+class InformationView(View, SignalsHelper):
     """
         View with artist information
     """
 
+    @signals_map
     def __init__(self, view_type, minimal=False):
         """
             Init artist infos
             @param view_type as ViewType
             @param minimal as bool
         """
-        View.__init__(self, get_default_storage_type(), view_type)
+        View.__init__(self, get_default_storage_type(),
+                      view_type | ViewType.OVERLAY)
         self.__information_store = InformationStore()
         self.__cancellable = Gio.Cancellable()
         self.__minimal = minimal
         self.__artist_name = ""
+        if minimal:
+            return []
+        else:
+            return [
+                (App().window, "notify::folded", "_on_container_folded"),
+            ]
 
     def populate(self, artist_id=None):
         """
             Show information for artists
             @param artist_id as int
         """
-        builder = Gtk.Builder()
-        builder.add_from_resource(
-            "/org/gnome/Lollypop/ArtistInformation.ui")
-        builder.connect_signals(self)
-        self.__scrolled = builder.get_object("scrolled")
-        widget = builder.get_object("widget")
-        self.add(widget)
-        self.__stack = builder.get_object("stack")
-        self.__listbox = builder.get_object("listbox")
-        self.__artist_label = builder.get_object("artist_label")
-        title_label = builder.get_object("title_label")
-        self.__artist_artwork = builder.get_object("artist_artwork")
-        bio_eventbox = builder.get_object("bio_eventbox")
-        artist_label_eventbox = builder.get_object("artist_label_eventbox")
-        bio_eventbox.connect("realize", set_cursor_type)
-        artist_label_eventbox.connect("realize", set_cursor_type)
-        self.__gesture1 = GesturesHelper(
-            bio_eventbox,
-            primary_press_callback=self._on_info_label_press)
-        self.__gesture2 = GesturesHelper(
-            artist_label_eventbox,
-            primary_press_callback=self._on_artist_label_press)
-        self.__bio_label = builder.get_object("bio_label")
-        if artist_id is None and App().player.current_track.id is not None:
-            builder.get_object("header").show()
-            if App().player.current_track.album.artist_ids[0] ==\
-                    Type.COMPILATIONS:
-                artist_id = App().player.current_track.artist_ids[0]
-            else:
-                artist_id = App().player.current_track.album.artist_ids[0]
-            title_label.set_text(App().player.current_track.title)
-        self.__artist_name = App().artists.get_name(artist_id)
-        if self.__minimal:
-            self.__bio_label.set_margin_start(MARGIN)
-            self.__bio_label.set_margin_end(MARGIN)
-            self.__bio_label.set_margin_top(MARGIN)
-            self.__bio_label.set_margin_bottom(MARGIN)
-            self.__artist_artwork.hide()
-        else:
-            self.__artist_artwork.set_margin_start(MARGIN_SMALL)
-            builder.get_object("header").show()
-            self.__artist_label.set_text(self.__artist_name)
-            self.__artist_label.show()
-            title_label.show()
-            App().art_helper.set_artist_artwork(
-                                    self.__artist_name,
-                                    ArtSize.SMALL * 3,
-                                    ArtSize.SMALL * 3,
-                                    self.__artist_artwork.get_scale_factor(),
-                                    ArtBehaviour.ROUNDED |
-                                    ArtBehaviour.CROP_SQUARE |
-                                    ArtBehaviour.CACHE,
-                                    self.__on_artist_artwork)
-            albums_view = AlbumsListView([], [],
-                                         ViewType.SCROLLED)
-            albums_view.set_size_request(300, -1)
-            albums_view.show()
-            albums_view.set_margin_start(5)
-            albums_view.add_widget(albums_view.box)
-            widget.attach(albums_view, 2, 1, 1, 2)
+        self.__banner = None
+        artist_ids = App().player.current_track.artist_ids\
+            if artist_id is None else [artist_id]
+        self.__artist_name = App().artists.get_name(artist_ids[0])
+        if not self.__minimal:
+            storage_type = App().player.current_track.storage_type
+            self.__banner = InformationBannerWidget(artist_ids[0])
+            self.__banner.show()
+            self.__banner.connect("search", self.__on_banner_search)
+            self.__albums_view = AlbumsListView([], [],
+                                                ViewType.SCROLLED |
+                                                ViewType.ARTIST)
+            self.__albums_view.set_size_request(350, -1)
+            self.__albums_view.show()
+            self.__albums_view.set_halign(Gtk.Align.END)
+            self.__albums_view.add_widget(self.__albums_view.box)
             albums = []
             storage_type = get_default_storage_type()
-            for album_id in App().albums.get_ids([], [artist_id],
+            for album_id in App().albums.get_ids([], artist_ids,
                                                  storage_type, True):
                 albums.append(Album(album_id))
             if not albums:
                 albums = [App().player.current_track.album]
-            albums_view.populate(albums)
+            self.__albums_view.populate(albums)
+        self.__listbox = Gtk.ListBox.new()
+        self.__listbox.show()
+        self.__listbox.get_style_context().add_class("trackswidget")
+        self.__listbox.connect("row-activated", self.__on_row_activated)
+        self.__listbox.set_hexpand(True)
+        self.__listbox.set_halign(Gtk.Align.CENTER)
+        self.__label = Gtk.Label.new()
+        self.__label.show()
+        self.__label.set_justify(Gtk.Justification.FILL)
+        self.__label.set_line_wrap(True)
+        self.__label.set_line_wrap_mode(Pango.WrapMode.WORD)
+        self.__label.set_valign(Gtk.Align.START)
+        self.__label.set_margin_top(MARGIN)
+        self.__label.set_margin_bottom(MARGIN)
+        self.__label.set_margin_start(MARGIN)
+        self.__label.set_margin_end(MARGIN)
+        self.__label.set_hexpand(True)
+        widget = Gtk.Grid()
+        widget.show()
+        self.__stack = Gtk.Stack.new()
+        self.__stack.show()
+        self.__stack.add(self.__label)
+        self.__stack.add(self.__listbox)
+        self.add_widget(widget, self.__banner)
+        widget.add(self.__stack)
+        if not self.__minimal:
+            widget.add(self.__albums_view)
+        self._on_container_folded()
         content = self.__information_store.get_information(self.__artist_name,
                                                            ARTISTS_PATH)
         if content is None:
-            self.__bio_label.set_text(_("Loading information"))
+            self.__label.set_text(_("Loading information"))
             from lollypop.information_downloader import InformationDownloader
             downloader = InformationDownloader()
             downloader.get_information(self.__artist_name,
@@ -165,7 +157,15 @@ class InformationView(View):
                                        self.__artist_name)
         else:
             App().task_helper.run(self.__to_markup, content,
-                                  callback=(self.__bio_label.set_markup,))
+                                  callback=(self.__label.set_markup,))
+
+    @property
+    def artist_name(self):
+        """
+            Get view artist
+            @return artist_name as str
+        """
+        return self.__artist_name
 
 #######################
 # PROTECTED           #
@@ -177,60 +177,35 @@ class InformationView(View):
         """
         self.__cancellable.cancel()
 
-    def _on_previous_button_clicked(self, button):
+    def _on_container_folded(self, *ignore):
         """
-            Go back to main view
-            @param button as Gtk.Button
+            Handle libhandy folded status
         """
-        self.__stack.set_visible_child_name("main")
-
-    def _on_artist_label_press(self, x, y, event):
-        """
-            Go to artist view
-            @param x as int
-            @param y as int
-            @param event as Gdk.Event
-        """
-        popover = self.get_ancestor(Gtk.Popover)
-        if popover is not None:
-            popover.popdown()
-        if App().player.current_track.id is None:
-            return
-        GLib.idle_add(App().window.container.show_view,
-                      [Type.ARTISTS],
-                      App().player.current_track.album.artist_ids)
-
-    def _on_info_label_press(self, x, y, event):
-        """
-            Show information cache (for edition)
-            @param x as int
-            @param y as int
-            @param event as Gdk.Event
-        """
-        if get_network_available("WIKIPEDIA"):
-            from lollypop.wikipedia import Wikipedia
-            wikipedia = Wikipedia()
-            self.__stack.set_visible_child_name("select")
-            App().task_helper.run(wikipedia.get_search_list,
-                                  self.__artist_name,
-                                  callback=(self.__on_wikipedia_search_list,))
-
-    def _on_row_activated(self, listbox, row):
-        """
-            Update artist information
-            @param listbox as Gtk.ListBox
-            @param row as Gtk.ListBoxRow
-        """
-        self.__stack.set_visible_child_name("main")
-        from lollypop.wikipedia import Wikipedia
-        wikipedia = Wikipedia()
-        App().task_helper.run(wikipedia.get_content_for_page_id,
-                              row.page_id, row.locale,
-                              callback=(self.__on_wikipedia_get_content,))
+        if not self.__minimal:
+            if App().window.folded:
+                if not self.view_type & ViewType.SMALL:
+                    self.__label.set_margin_start(MARGIN)
+                    self.__label.set_margin_end(MARGIN)
+                    self.__label.get_style_context().remove_class("text-large")
+                self.__albums_view.hide()
+            else:
+                if not self.view_type & ViewType.SMALL:
+                    self.__label.set_margin_start(100)
+                    self.__label.set_margin_end(100)
+                    self.__label.get_style_context().add_class("text-large")
+                self.__albums_view.show()
 
 #######################
 # PRIVATE             #
 #######################
+    def __show_main_widget(self):
+        """
+            Show main widget in stack
+        """
+        self.__listbox.hide()
+        self.__label.show()
+        self.__stack.set_visible_child(self.__label)
+
     def __to_markup(self, data):
         """
             Transform message to markup
@@ -249,15 +224,43 @@ class InformationView(View):
             i += 1
         return text
 
+    def __on_banner_search(self, banner, status):
+        """
+            Search for artist
+            @param banner as InformationBannerwidget
+            @param status as bool
+        """
+        if status:
+            self.__label.set_text(_("Loading information"))
+            if get_network_available("WIKIPEDIA"):
+                from lollypop.helper_web_wikipedia import WikipediaHelper
+                wikipedia = WikipediaHelper()
+                self.__label.hide()
+                self.__listbox.show()
+                self.__stack.set_visible_child(self.__listbox)
+                App().task_helper.run(
+                    wikipedia.get_search_list,
+                    self.__artist_name,
+                    callback=(self.__on_wikipedia_search_list,))
+            else:
+                self.__banner.button.toggled()
+        else:
+            self.__show_main_widget()
+
     def __on_wikipedia_search_list(self, items):
         """
             Populate view with items
             @param items as [(str, str)]
         """
-        for item in items:
-            row = ArtistRow(item)
-            row.show()
-            self.__listbox.add(row)
+        if items:
+            for item in items:
+                row = ArtistRow(item)
+                row.show()
+                self.__listbox.add(row)
+        else:
+            self.__show_main_widget()
+            self.__label.set_text(
+                _("No information for %s") % self.__artist_name)
 
     def __on_wikipedia_get_content(self, content):
         """
@@ -266,7 +269,7 @@ class InformationView(View):
         """
         if content is not None:
             App().task_helper.run(self.__to_markup, content,
-                                  callback=(self.__bio_label.set_markup,))
+                                  callback=(self.__label.set_markup,))
             self.__information_store.save_information(
                 self.__artist_name, ARTISTS_PATH, content)
 
@@ -287,14 +290,27 @@ class InformationView(View):
             @param content as bytes
             @param artist_name as str
         """
-        if artist_name != self.__artist_name:
-            return
         if content is None:
-            self.__bio_label.set_text(
+            self.__show_main_widget()
+            self.__label.set_text(
                 _("No information for %s") % self.__artist_name)
         else:
             App().task_helper.run(self.__to_markup, content,
-                                  callback=(self.__bio_label.set_markup,))
+                                  callback=(self.__label.set_markup,))
             self.__information_store.save_information(self.__artist_name,
                                                       ARTISTS_PATH,
                                                       content)
+
+    def __on_row_activated(self, listbox, row):
+        """
+            Update artist information
+            @param listbox as Gtk.ListBox
+            @param row as Gtk.ListBoxRow
+        """
+        self.__show_main_widget()
+        self.__banner.button.set_active(False)
+        from lollypop.helper_web_wikipedia import WikipediaHelper
+        wikipedia = WikipediaHelper()
+        App().task_helper.run(wikipedia.get_content_for_page_id,
+                              row.page_id, row.locale,
+                              callback=(self.__on_wikipedia_get_content,))
